@@ -102,7 +102,8 @@ static Bool LoadPYBaseDict(void)
     fc.freqOrder = AD_NO;
 
     FILE *fp;
-    int i, j, iLen;
+    int i, j;
+    uint iLen;
 
     fp = fopen(PY_BASE_FILE, "r");
     if (!fp)
@@ -121,9 +122,9 @@ static Bool LoadPYBaseDict(void)
             fread(&len, sizeof(INT8), 1, fp);
             fread(PYFAList[i].pyBase[j].strHZ, sizeof(char) * len, 1, fp);
             PYFAList[i].pyBase[j].strHZ[len] = '\0';
-            fread(&iLen, sizeof(int), 1, fp);
+            fread(&iLen, sizeof(uint), 1, fp);
             PYFAList[i].pyBase[j].iIndex = iLen;
-            PYFAList[i].pyBase[j].iHit = 0;
+            PYFAList[i].pyBase[j].iHit = iLen;
             PYFAList[i].pyBase[j].flag = 0;
             if (iLen > iCounter)
                 iCounter = iLen;
@@ -146,7 +147,8 @@ static Bool LoadPYBaseDict(void)
 }
 static void LoadPYPhraseDict(FILE *fp, Bool isSystem)
 {
-    int i, j ,k, count, iLen;
+    uint iLen;
+    int i, j ,k, count;
     char strBase[UTF8_MAX_LENGTH + 1];
     PyPhrase *temp, *phrase;
     while (!feof(fp)) {
@@ -187,7 +189,7 @@ static void LoadPYPhraseDict(FILE *fp, Bool isSystem)
             phrase->strPhrase = (char *) malloc(sizeof(char) * (iLen + 1));
             fread(phrase->strPhrase, sizeof(char) * iLen, 1, fp);
             phrase->strPhrase[iLen] = '\0';
-            fread(&iLen, sizeof(unsigned int), 1, fp);
+            fread(&iLen, sizeof(uint), 1, fp);
             phrase->iIndex = iLen;
             if (iLen > iCounter)
                 iCounter = iLen;
@@ -271,9 +273,9 @@ static Bool LoadPYOtherDict(void)
 {
     //下面开始读系统词组
     FILE *fp;
-    int i, j, k, iLen;
+/*    int i, j, k, iLen;
     uint iIndex;
-
+*/
     bPYOtherDictLoaded = True;
 
     fp = fopen(PY_PHRASE_FILE, "r");
@@ -283,6 +285,7 @@ static Bool LoadPYOtherDict(void)
         LoadPYPhraseDict(fp, True);
         fclose(fp);
     }
+#if 0
     //下面读取索引文件
     fp = fopen(PY_INDEX_FILE, "rb");
     if (fp) {
@@ -313,6 +316,7 @@ static Bool LoadPYOtherDict(void)
 
         fclose(fp);
     }
+#endif
     return True;
 }
 
